Env

Struct Env 

pub struct Env { /* private fields */ }
Safe wrapper around std::env::vars_os, which is safe to access on Windows: some of its environmental variables are case-insensitive.

Implementations

Source

impl Env

pub fn new() -> Self

Create new default Env.

pub fn new_from(env: HashMap<OsString, OsString>) -> Self

Create new Env using env as existing environmental variables.

pub fn reload_from(&mut self, env: HashMap<OsString, OsString>)

Reload environmental variables from env.

pub fn reload(&mut self)

Reload environmental variables from std::env::vars_os.

pub fn get_os(&self, key: impl AsRef<OsStr>) -> Option<&OsStr>

Get environmental variable pointed by key.

Arguments
  • key - key for environmental variable. Must implement AsRef<OsStr>.
Returns

Option<&OsStr>. None variant indicates missing key, Some: existing key.

Examples
use rustvil::os::env::Env;

let env = Env::new();
println!("$FOO = {:?}", env.get_os("FOO"));
pub fn has(&self, key: impl AsRef<OsStr>) -> bool

Check, whether this Env has key key.

pub fn get(&self, key: impl AsRef<OsStr>) -> Result<&str, EnvStrError>

Get environmental variable pointed by key and convert it to UTF-8.

Arguments
  • key - key for environmental variable. Must implement AsRef<Str>.
Returns

Result<&str, EnvStrError>. Ok variant indicates existing UTF-8 variable, Err indicates some kind of error. See EnvStrError for details.

Examples
use rustvil::os::env::Env;

let env = Env::new();
let _path = env.get("PATH")?;